summaryrefslogtreecommitdiffstats
path: root/pkgs/development/compilers/gcc/4.2-apple64/builder.sh
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/compilers/gcc/4.2-apple64/builder.sh')
-rw-r--r--pkgs/development/compilers/gcc/4.2-apple64/builder.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/development/compilers/gcc/4.2-apple64/builder.sh b/pkgs/development/compilers/gcc/4.2-apple64/builder.sh
index 036678460d60..4a4fb476a358 100644
--- a/pkgs/development/compilers/gcc/4.2-apple64/builder.sh
+++ b/pkgs/development/compilers/gcc/4.2-apple64/builder.sh
@@ -14,11 +14,11 @@ if test "$noSysDirs" = "1"; then
# Figure out what extra flags to pass to the gcc compilers being
# generated to make sure that they use our glibc.
- if test -e $NIX_GCC/nix-support/orig-glibc; then
- glibc=$(cat $NIX_GCC/nix-support/orig-glibc)
+ if test -e $NIX_CC/nix-support/orig-glibc; then
+ glibc=$(cat $NIX_CC/nix-support/orig-glibc)
# Ugh. Copied from gcc-wrapper/builder.sh. We can't just
# source in $NIX_GCC/nix-support/add-flags, since that would
# cause *this* GCC to be linked against the *previous* GCC.
# Need some more modularity there.
extraCFlags="-B$glibc/lib -isystem $glibc/include"
@@ -14,11 +14,11 @@ if test "$noSysDirs" = "1"; then
# Ugh. Copied from gcc-wrapper/builder.sh. We can't just
- # source in $NIX_GCC/nix-support/add-flags, since that would
+ # source in $NIX_CC/nix-support/add-flags, since that would
# cause *this* GCC to be linked against the *previous* GCC.
# Need some more modularity there.